==> haskell-tree-diff-0.2.1.1-59-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tree-diff.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tree-diff
version:              0.2.1.1
visibility:           public
id:                   tree-diff-0.2.1.1-EyKLKAQtpIf46DYpS6BGE2
key:                  tree-diff-0.2.1.1-EyKLKAQtpIf46DYpS6BGE2
license:              GPL-2.0-or-later
copyright:            (c) 2017-2021 Oleg Grenrus
maintainer:           Oleg.Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/tree-diff
synopsis:             Diffing of (expression) trees.
description:
    Common diff algorithm works on list structures:

    @
    diff :: Eq a => [a] -> [a] -> [Edit a]
    @

    This package works on trees.

    @
    treeDiff :: Eq a => Tree a -> Tree a -> Edit (EditTree a)
    @

    This package also provides a way to diff arbitrary ADTs,
    using @Generics@-derivable helpers.

    This package differs from <http://hackage.haskell.org/package/gdiff gdiff>,
    in a two ways: @tree-diff@ doesn'\''t have patch function,
    and the "edit-script" is a tree itself, which is useful for pretty-printing.

    @
    >>> prettyEditExpr $ ediff (Foo 42 [True, False] "old") (Foo 42 [False, False, True] "new")
    Foo
    \  {fooBool = [-True, +False, False, +True],
    \   fooInt = 42,
    \   fooString = -"old" +"new"}
    @

category:             Data, Testing
abi:                  570f26682d0dfa5ec09563dad3753ce2
exposed:              True
exposed-modules:
    Data.TreeDiff Data.TreeDiff.Class Data.TreeDiff.Expr
    Data.TreeDiff.Golden Data.TreeDiff.List Data.TreeDiff.OMap
    Data.TreeDiff.Parser Data.TreeDiff.Pretty Data.TreeDiff.QuickCheck
    Data.TreeDiff.Tree

import-dirs:          /usr/lib/ghc-9.0.2/site-local/tree-diff-0.2.1.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/tree-diff-0.2.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tree-diff
hs-libraries:         HStree-diff-0.2.1.1-EyKLKAQtpIf46DYpS6BGE2
depends:
    QuickCheck-2.14.2-7iK1DMIteZqGNM8TzExDZa
    aeson-1.5.6.0-9Pr07X4KYAQGYkzJzuJMP6
    ansi-terminal-0.11.1-78y8MvYqyGh2ibnhIzekfU
    ansi-wl-pprint-0.6.9-I8vypCNqpid9s7jiSTXJMJ base-4.15.1.0
    base-compat-0.12.1-Jgs1a6JPC25AMVxb7dCwve bytestring-0.10.12.1
    containers-0.6.4.1 deepseq-1.4.5.0
    hashable-1.4.0.2-J44BDnT4N4jIfsjZsKg5ZQ parsec-3.1.14.0
    parsers-0.12.11-1S795CseMuSLPuiDMroVXV pretty-1.1.3.6
    primitive-0.7.4.0-1OkI0w4vVkZAnKazzRI3t
    scientific-0.3.7.0-48Wj4PpHzxKAvlz1kMpDrM
    semialign-1.2.0.1-4k7T2My6oJlH8I9YUB6qLH
    strict-0.4.0.1-3Q68R3u9lpUKSHU8714x0p
    tagged-0.8.6.1-79gYUUazit6EfoPS33FHdR text-1.2.5.0
    these-1.1.1.1-FC30viIJxBZERnZV276NIC time-1.9.3
    unordered-containers-0.2.19.1-BhRjg5By7kU7pLGfSxEo3F
    uuid-types-1.0.5-DRoQNIXhD7x3kXg14poErG
    vector-0.12.3.1-J4wWiZyTUBGFVf3h0yMQvX

haddock-interfaces:   /usr/share/doc/haskell-tree-diff/html/tree-diff.haddock
haddock-html:         /usr/share/doc/haskell-tree-diff/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tree-diff-0.2.1.1-65-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tree-diff.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tree-diff
version:              0.2.1.1
visibility:           public
id:                   tree-diff-0.2.1.1-CxeoTVyg0nY47lPx32egjP
key:                  tree-diff-0.2.1.1-CxeoTVyg0nY47lPx32egjP
license:              GPL-2.0-or-later
copyright:            (c) 2017-2021 Oleg Grenrus
maintainer:           Oleg.Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/tree-diff
synopsis:             Diffing of (expression) trees.
description:
    Common diff algorithm works on list structures:

    @
    diff :: Eq a => [a] -> [a] -> [Edit a]
    @

    This package works on trees.

    @
    treeDiff :: Eq a => Tree a -> Tree a -> Edit (EditTree a)
    @

    This package also provides a way to diff arbitrary ADTs,
    using @Generics@-derivable helpers.

    This package differs from <http://hackage.haskell.org/package/gdiff gdiff>,
    in a two ways: @tree-diff@ doesn'\''t have patch function,
    and the "edit-script" is a tree itself, which is useful for pretty-printing.

    @
    >>> prettyEditExpr $ ediff (Foo 42 [True, False] "old") (Foo 42 [False, False, True] "new")
    Foo
    \  {fooBool = [-True, +False, False, +True],
    \   fooInt = 42,
    \   fooString = -"old" +"new"}
    @

category:             Data, Testing
abi:                  e7479323283f34c0513b61a2a6fddc80
exposed:              True
exposed-modules:
    Data.TreeDiff Data.TreeDiff.Class Data.TreeDiff.Expr
    Data.TreeDiff.Golden Data.TreeDiff.List Data.TreeDiff.OMap
    Data.TreeDiff.Parser Data.TreeDiff.Pretty Data.TreeDiff.QuickCheck
    Data.TreeDiff.Tree

import-dirs:          /usr/lib/ghc-9.0.2/site-local/tree-diff-0.2.1.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/tree-diff-0.2.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tree-diff
hs-libraries:         HStree-diff-0.2.1.1-CxeoTVyg0nY47lPx32egjP
depends:
    QuickCheck-2.14.2-7IscL6Ui3Th4idiIZNtA9m
    aeson-1.5.6.0-D6JFXMoVVY440Mpm8YlAiW
    ansi-terminal-0.11.2-B0AY9PdIvzL5E0D3UtnNRn
    ansi-wl-pprint-0.6.9-L6JfTPW66HSIQalRJU4ZxP base-4.15.1.0
    base-compat-0.12.1-Jgs1a6JPC25AMVxb7dCwve bytestring-0.10.12.1
    containers-0.6.4.1 deepseq-1.4.5.0
    hashable-1.4.0.2-BtUN60XU2rZ3DwXWIBThsB parsec-3.1.14.0
    parsers-0.12.11-HZsnwrXT6R3E81qSWoNrPx pretty-1.1.3.6
    primitive-0.7.4.0-ApwAailRBWz8tJqPYVRiUV
    scientific-0.3.7.0-2bBilO5AY4p7o0WHMnmlyC
    semialign-1.2.0.1-6EUPe2K7xZ7J99axsIpCuh
    strict-0.4.0.1-4msyjOJn0HUF7E58QLkgro
    tagged-0.8.6.1-79gYUUazit6EfoPS33FHdR text-1.2.5.0
    these-1.1.1.1-DHELk52hqxz5r3GBi6X0CS time-1.9.3
    unordered-containers-0.2.19.1-7SQ4DJN6rki64sevxnHKhZ
    uuid-types-1.0.5-4qkFb4qx5GGHjlKxT1TAny
    vector-0.12.3.1-Im4rxp8YGWIHuHWC3z5rRi

haddock-interfaces:   /usr/share/doc/haskell-tree-diff/html/tree-diff.haddock
haddock-html:         /usr/share/doc/haskell-tree-diff/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
